@@ -491,6 +491,7 @@ class Experimento:
 
         self.matriz_cuadriculada_solo_regiones_preferidas = np.flipud(self.matriz_cuadriculada_solo_regiones_preferidas)
 
+        print("Matriz cuadriculada, solo regiones preferidas", self.matriz_cuadriculada_solo_regiones_preferidas)
 
     def genera_matriz_cuadriculada_solo_regiones_no_preferidas(self):
         matriz_cuadriculada_plana = np.flipud(self.matriz_cuadriculada).flatten()
@@ -507,6 +508,8 @@ class Experimento:
 
         self.matriz_cuadriculada_solo_regiones_no_preferidas = np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas)
 
+        print("Matriz cuadriculada, solo regiones no preferidas", self.matriz_cuadriculada_solo_regiones_no_preferidas)
+
     def calcula_matrices_de_recurrencia(self):
 
         self.obtener_indice_regiones_objeto()
@@ -1249,7 +1252,7 @@ class Experimento:
                                                                         series_tiempo=series_tiempo)
 
             for indice in range(0, len(indices_tiempo)):
-                plt.scatter(indices_tiempo[indice], series_tiempo[indice], color='blue')
+                plt.scatter(indices_tiempo[indice], series_tiempo[indice], color='blue',  s=1)
                 plt.plot(indices_tiempo[indice], resultados[indice], color='red')
 
         elif grafica == 'cilindros_objetos_importantes':
